@@ -1,7 +1,7 @@
 package App::BencherUtils;
 
-our $DATE = '2016-06-26'; # DATE
-our $VERSION = '0.15'; # VERSION
+our $DATE = '2016-07-13'; # DATE
+our $VERSION = '0.16'; # VERSION
 
 use 5.010001;
 use strict;
@@ -413,6 +413,28 @@ sub list_bencher_scenario_modules {
     [200, "OK", \@res];
 }
 
+$SPEC{format_bencher_result} = {
+    v => 1.1,
+    summary => '',
+    args => {
+        json => {
+            summary => 'JSON data',
+            schema => 'str*', # XXX filename
+            req => 1,
+            pos => 0,
+            cmdline_src => 'stdin_or_file',
+        },
+    },
+};
+sub format_bencher_result {
+    require Bencher::Backend;
+
+    my %args = @_;
+    my $res = _json->decode($args{json});
+    [200, "OK", Bencher::Backend::format_result($res),
+     {'cmdline.skip_format'=>1}];
+}
+
 1;
 # ABSTRACT: Utilities related to bencher
 
@@ -428,7 +450,7 @@ App::BencherUtils - Utilities related to bencher
 
 =head1 VERSION
 
-This document describes version 0.15 of App::BencherUtils (from Perl distribution App-BencherUtils), released on 2016-06-26.
+This document describes version 0.16 of App::BencherUtils (from Perl distribution App-BencherUtils), released on 2016-07-13.
 
 =head1 SYNOPSIS
 
@@ -440,6 +462,8 @@ This distribution includes several utilities:
 
 =item * L<cleanup-old-bencher-results>
 
+=item * L<format-bencher-result>
+
 =item * L<list-bencher-results>
 
 =item * L<list-bencher-scenario-modules>
@@ -504,6 +528,32 @@ that contains extra information.
 Return value:  (any)
 
 
+=head2 format_bencher_result(%args) -> [status, msg, result, meta]
+
+This function is not exported.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<json>* => I<str>
+
+JSON data.
+
+=back
+
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (result) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
+Return value:  (any)
+
+
 =head2 list_bencher_results(%args) -> [status, msg, result, meta]
 
 List results in results directory.
